@@ -2,7 +2,7 @@
  *
  * client main program
  *
- * $Id: lsh.c,v 1.102 2000/03/16 22:38:05 nisse Exp $ */
+ * $Id: lsh.c,v 1.103 2000/04/02 19:33:25 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -333,7 +333,7 @@ make_options_command(struct lsh_options *options,
 static struct verifier *
 do_lsh_lookup(struct lookup_verifier *c,
 	      int method,
-	      struct user *keyholder UNUSED,
+	      struct lsh_user *keyholder UNUSED,
 	      struct lsh_string *key)
 {
   CAST(lsh_host_db, self, c);
