@@ -1,6 +1,6 @@
 /* lsh.h
  *
- * $Id: lsh.h,v 1.13 2000/02/22 20:48:19 nisse Exp $ */
+ * $Id: lsh.h,v 1.14 2000/04/02 19:33:26 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -123,6 +123,6 @@ struct sexp;
 struct sexp_iterator;
 
 /* userauth.h */
-struct user;
+struct lsh_user;
 
 #endif /* LSH_H_INCLUDED */
