@@ -2,7 +2,7 @@
  *
  * main proxy program.
  *
- * $Id: lsh_proxy.c,v 1.8 2000/03/26 20:38:32 nisse Exp $ */
+ * $Id: lsh_proxy.c,v 1.9 2000/04/02 19:33:27 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -398,7 +398,7 @@ main_argp =
 static struct verifier *
 do_host_lookup(struct lookup_verifier *c UNUSED,
 	       int method UNUSED,
-               struct user *user UNUSED,
+               struct lsh_user *user UNUSED,
                struct lsh_string *key)
 {
   assert(method == ATOM_SSH_DSS);
